@@ -51,7 +51,6 @@ class Crawlers extends AbstractProvider
         'a3logics\.in',
         'A6-Indexer',
         'a\.pr-cy\.ru',
-        'Abonti\/',
         'Aboundex',
         'aboutthedomain',
         'Accoona-AI-Agent',
@@ -67,12 +66,10 @@ class Crawlers extends AbstractProvider
         'aihit',
         'aiohttp\/',
         'Airmail',
-        'akka-http\/',
         'akula\/',
         'alertra',
         'alexa site audit',
         'Alibaba\.Security\.Heimdall',
-        'allloadin\.com',
         'alyze\.info',
         'amagit',
         'AndroidDownloadManager',
@@ -80,11 +77,8 @@ class Crawlers extends AbstractProvider
         'Ant\.com',
         'Anturis Agent',
         'AnyEvent-HTTP\/',
-        'ApacheBench\/',
-        'Apache-HttpAsyncClient\/',
         'Apache-HttpClient\/',
         'AportWorm\/[0-9]',
-        'AppBeat\/[0-9]',
         'AppEngine-Google',
         'Arachmo',
         'arachnode',
@@ -97,7 +91,6 @@ class Crawlers extends AbstractProvider
         'autocite',
         'Autonomy',
         'B-l-i-t-z-B-O-T',
-        '^b0t$',
         'Backlink-Ceck\.de',
         'Bad-Neighborhood',
         'baidu\.com',
@@ -124,7 +117,6 @@ class Crawlers extends AbstractProvider
         'Braintree-Webhooks',
         'Branch Metrics API',
         'Branch-Passthrough',
-        'Brodie\/',
         'Browsershots',
         'BUbiNG',
         'Butterfly\/',
@@ -140,20 +132,15 @@ class Crawlers extends AbstractProvider
         'CERT\.at-Statistics-Survey',
         'cg-eye',
         'changedetection',
-        'ChangesMeter\/',
         'Charlotte',
         'CheckHost',
         'checkprivacy',
         'chkme\.com',
-        'Chirp\/[0-9]',
         'CirrusExplorer\/',
         'CISPA Vulnerability Notification',
-        'Citoid',
         'CJNetworkQuality',
-        'Clarsentia',
         'clips\.ua\.ac\.be',
         'Cloud mapping experiment',
-        'CloudEndure',
         'CloudFlare-AlwaysOnline',
         'Cloudinary\/[0-9]',
         'cmcm\.com',
@@ -182,13 +169,12 @@ class Crawlers extends AbstractProvider
         'Digg',
         'Dispatch\/',
         'dlvr',
-        'DMBrowser',
+        'DMBrowser-UV',
         'DNS-Tools Header-Analyzer',
         'DNSPod-reporting',
         'docoloc',
         'Dolphin http client\/',
         'DomainAppender',
-        'Donuts Content Explorer',
         'dotSemantic',
         'downforeveryoneorjustme',
         'downnotifier\.com',
@@ -202,8 +188,6 @@ class Crawlers extends AbstractProvider
         'ec2linkfinder',
         'eCairn-Grabber',
         'ECCP',
-        'echocrawl',
-        'eContext\/',
         'ElectricMonk',
         'elefent',
         'EMail Exractor',
@@ -220,13 +204,11 @@ class Crawlers extends AbstractProvider
         'Excel\/',
         'Exif Viewer',
         'Exploratodo',
-        'Express WebPictures',
         'ezooms',
         'facebookexternalhit',
         'facebookplatform',
         'fairshare',
         'Faraday v',
-        'fasthttp',
         'Faveeo',
         'Favicon downloader',
         'FavOrg',
@@ -256,7 +238,6 @@ class Crawlers extends AbstractProvider
         'free thumbnails',
         'FreeWebMonitoring SiteChecker',
         'Funnelback',
-        'G-i-g-a-b-o-t',
         'g00g1e\.net',
         'GAChecker',
         'ganarvisitas\/[0-9]',
@@ -267,13 +248,10 @@ class Crawlers extends AbstractProvider
         'GetLinkInfo',
         'getprismatic\.com',
         'GetURLInfo\/[0-9]',
-        'Ghost Inspector',
         'GigablastOpenSource',
-        'GIS-LABS',
         'github\.com\/',
         'Go [\d\.]* package http',
         'Go-http-client',
-        'gobyus',
         'gofetch',
         'GomezAgent',
         'gooblog',
@@ -288,7 +266,6 @@ class Crawlers extends AbstractProvider
         'Google-Adwords',
         'Google-Apps-Script',
         'Google-Calendar-Importer',
-        'Google-HotelAdsVerifier',
         'Google-HTTP-Java-Client',
         'Google-Publisher-Plugin',
         'Google-SearchByImage',
@@ -299,18 +276,16 @@ class Crawlers extends AbstractProvider
         'GoogleDocs',
         'GoogleHC\/',
         'GoogleProducer',
-        'Gookey',
         'GoScraper',
         'GoSpotCheck',
         'GoSquared-Status-Checker',
         'gosquared-thumbnailer',
+        'GotSiteMonitor',
         'grabify',
         'Grammarly',
         'grouphigh',
-        'grokkit',
         'grub-client',
         'GTmetrix',
-        'GuzzleHttp',
         'gvfs\/',
         'HAA(A)?RTLAND http client',
         'Hatena',
@@ -318,7 +293,6 @@ class Crawlers extends AbstractProvider
         'HEADMasterSEO',
         'HeartRails_Capture',
         'heritrix',
-        'historious\/',
         'hledejLevne\.cz\/[0-9]',
         'Holmes',
         'HootSuite Image proxy',
@@ -327,10 +301,8 @@ class Crawlers extends AbstractProvider
         'ht:\/\/check',
         'htdig',
         'HTMLParser\/',
-        'http-get',
         'HTTP-Header-Abfrage',
         'http-kit',
-        'http-request\/',
         'HTTP-Tiny',
         'HTTP_Compression_Test',
         'http_request2',
@@ -360,7 +332,6 @@ class Crawlers extends AbstractProvider
         'IlTrovatore',
         'ImageEngine\/',
         'Imagga',
-        'imgsizer',
         'InAGist',
         'inbound\.li parser',
         'InDesign%20CC',
@@ -374,7 +345,6 @@ class Crawlers extends AbstractProvider
         'internet_archive',
         'InternetSeer',
         'internetVista monitor',
-        'intraVnews',
         'IODC',
         'IOI',
         'iplabel',
@@ -387,33 +357,25 @@ class Crawlers extends AbstractProvider
         'iskanie',
         'iZSearch',
         'janforman',
-        'Jaunt\/',
-        'Jersey\/',
         'Jigsaw',
         'Jobboerse',
-        'Jobg8 URL Monitor',
         'jobo',
         'Jobrapido',
         'JS-Kit',
-        'Kaspersky Lab CFR link resolver',
         'KeepRight OpenStreetMap Checker',
-        'Kelny\/',
-        'Kerrigan\/',
-        'KeyCDN',
-        'Keyword Extractor',
+        'KeyCDN Perf Test',
         'Keywords Research',
         'KickFire',
         'KimonoLabs\/',
         'Kml-Google',
         'knows\.is',
-        'KOCMOHABT',
         'kouio',
+        'KrOWLer',
         'kulturarw3',
         'KumKie',
         'L\.webis',
         'Larbin',
         'LayeredExtractor',
-        'letsencrypt',
         'LibVLC',
         'libwww',
         'Licorne Image Snapshot',
@@ -436,18 +398,16 @@ class Crawlers extends AbstractProvider
         'LongURL API',
         'looksystems\.net',
         'ltx71',
-        'lua-resty-http',
         'lwp-trivial',
         'lycos',
         'LYT\.SR',
         'mabontland',
         'MagpieRSS',
         'Mail.Ru',
-        'MailChimp',
+        'MailChimp\.com',
         'Mandrill',
         'MapperCmd',
         'marketinggrader',
-        'masscan\/[0-9]',
         'Mediapartners-Google',
         'MegaIndex\.ru',
         'Melvil Rawi\/',
@@ -463,7 +423,6 @@ class Crawlers extends AbstractProvider
         'Miniflux',
         'mixdata dot com',
         'mixed-content-scan',
-        'mixnode',
         'Mnogosearch',
         'mogimogi',
         'Mojolicious \(Perl\)',
@@ -474,20 +433,16 @@ class Crawlers extends AbstractProvider
         'Moreover',
         'Morning Paper',
         'mowser',
-        'MovableType',
         'Mrcgiguy',
         'mShots',
-        'MxToolbox\/',
         'MVAClient',
         'nagios',
         'Najdi\.si\/',
         'Needle\/',
         'NETCRAFT',
         'NetLyzer FastProbe',
-        'Netpursual',
         'netresearch',
         'NetShelter ContentScan',
-        'Netsparker',
         'NetTrack',
         'Netvibes',
         'Neustar WPM',
@@ -516,7 +471,6 @@ class Crawlers extends AbstractProvider
         'okhttp',
         'Omea Reader',
         'omgili',
-        'OMSC',
         'Online Domain Tools',
         'OpenCalaisSemanticProxy',
         'Openstat\/',
@@ -524,7 +478,6 @@ class Crawlers extends AbstractProvider
         'Optimizer',
         'Orbiter',
         'OrgProbe\/[0-9]',
-        'Owler',
         'ow\.ly',
         'ownCloud News',
         'OxfordCloudService\/[0-9]',
@@ -543,13 +496,11 @@ class Crawlers extends AbstractProvider
         'peerindex',
         'Peew',
         'PhantomJS\/',
-        'PhantomJS Screenshoter',
         'Photon\/',
         'phpcrawl',
         'phpservermon',
         'Pi-Monster',
         'ping\.blo\.gs\/',
-        'Pingability',
         'Pingdom',
         'Pingoscope',
         'PingSpot',
@@ -558,7 +509,6 @@ class Crawlers extends AbstractProvider
         'Ploetz \+ Zeller',
         'Plukkie',
         'PocketParser',
-        'POE-Component-Client-HTTP\/',
         'Pompos',
         'Porkbun',
         'Port Monitor',
@@ -575,7 +525,6 @@ class Crawlers extends AbstractProvider
         'prospectb2b',
         'Protopage',
         'proximic',
-        'PRTG Network Monitor',
         'pshtt, https scanning',
         'PTST ',
         'PTST\/[0-9]+',
@@ -594,7 +543,6 @@ class Crawlers extends AbstractProvider
         'Readability',
         'RealPlayer%20Downloader',
         'RebelMouse',
-        'RecurPost\/',
         'redback\/',
         'Redirect Checker Tool',
         'ReederForMac',
@@ -613,7 +561,6 @@ class Crawlers extends AbstractProvider
         'SalesIntelligent',
         'SauceNAO',
         'SBIder',
-        'scalaj-http',
         'Scoop',
         'scooter',
         'ScoutJet',
@@ -622,7 +569,6 @@ class Crawlers extends AbstractProvider
         'ScreenShotService\/[0-9]',
         'Scrubby',
         'search\.thunderstone',
-        'Search37\/',
         'SearchSight',
         'Seeker',
         'semanticdiscovery',
@@ -645,10 +591,8 @@ class Crawlers extends AbstractProvider
         'ShortLinkTranslate',
         'shrinktheweb',
         'SilverReader',
-        'Sideqik',
         'SimplePie',
         'SimplyFast',
-        'SiteIndexed',
         'Site-Shot\/',
         'Site24x7',
         'SiteBar',
@@ -657,13 +601,10 @@ class Crawlers extends AbstractProvider
         'SiteGuardian',
         'Siteimprove\.com',
         'Sitemap(s)? Generator',
-        'SiteMonitor',
         'Siteshooter B0t',
-        'SiteSucker',
         'SiteTruth',
         'sitexy\.com',
         'SkypeUriPreview',
-        'Slack\/',
         'slider\.com',
         'slurp',
         'SMRF URL Expander',
@@ -674,7 +615,6 @@ class Crawlers extends AbstractProvider
         'Snoopy',
         'sogou web',
         'SortSite',
-        'sovereign\.ai',
         'spaziodati',
         'Specificfeeds',
         'speedy',
@@ -682,11 +622,9 @@ class Crawlers extends AbstractProvider
         'Spinn3r',
         'spray-can',
         'Sprinklr ',
-        'sqlmap',
         'spyonweb',
         'Sqworm',
         'SSL Labs',
-        'ssl-tools',
         'StackRambler',
         'Statastico\/',
         'StatusCake',
@@ -701,11 +639,9 @@ class Crawlers extends AbstractProvider
         'Symfony2 BrowserKit',
         'SynHttpClient-Built',
         'Sysomos',
-        'Symfony BrowserKit',
         'T0PHackTeam',
         'Tarantula\/',
         'Taringa UGC',
-        'Tenon\.io',
         'teoma',
         'terrainformatica\.com',
         'Test Certificate Info',
@@ -718,14 +654,10 @@ class Crawlers extends AbstractProvider
         'ThumbSniper',
         'TinEye',
         'Tiny Tiny RSS',
-        'TLSProbe\/',
         'topster',
         'touche.com',
         'Traackr.com',
-        'TrapitAgent',
-        'trendspottr\.com',
         'truwoGPS',
-        'TulipChain',
         'tweetedtimes\.com',
         'Tweetminster',
         'Tweezler\/',
@@ -733,21 +665,16 @@ class Crawlers extends AbstractProvider
         'Twingly',
         'ubermetrics-technologies',
         'uclassify',
-        'uCrawlr\/',
         'UdmSearch',
-        'UniversalFeedParser',
         'Untiny',
         'UnwindFetchor',
         'updated',
         'Upflow',
-        'Uptimia',
-        'URL Verifier',
         'URLChecker',
         'URLitor.com',
         'urlresolver',
         'Urlstat',
         'UrlTrends Ranking Updater',
-		'u-tokyo',		// added by Magic3
         'Vagabondo',
         'vBSEO',
         'via ggpht\.com GoogleImageProxy',
@@ -758,7 +685,6 @@ class Crawlers extends AbstractProvider
         'voyager\/',
         'VSAgent\/[0-9]',
         'VSB-TUO\/[0-9]',
-        'Vulnbusters Meter',
         'VYU2',
         'w3af\.org',
         'W3C-checklink',
@@ -787,7 +713,6 @@ class Crawlers extends AbstractProvider
         'webscreenie',
         'Webshot',
         'Website Analyzer\/',
-        'websitepulse agent',
         'websitepulse[+ ]checker',
         'Websnapr\/',
         'Webthumb\/[0-9]',
@@ -803,7 +728,6 @@ class Crawlers extends AbstractProvider
         'WhatWeb',
         'WhereGoes\?',
         'Whibse',
-        'WhoRunsCoinHive',
         'Whynder Magnet',
         'Windows-RSS-Platform',
         'WinHttpRequest',
@@ -814,7 +738,6 @@ class Crawlers extends AbstractProvider
         'WordPress\/',
         'wotbox',
         'WP Engine Install Performance API',
-        'wpif',
         'wprecon\.com survey',
         'WPScan',
         'wscheck',
@@ -833,7 +756,7 @@ class Crawlers extends AbstractProvider
         'YahooCacheSystem',
         'YahooYSMcm',
         'YandeG',
-        'Yandex(?!Search)',
+        'yandex',
         'yanga',
         'yeti',
         ' YLT',
