@@ -60,6 +60,6 @@ class Exclusions extends AbstractProvider
         'Opera Mini\/\d{1,2}\.\d{1,2}\.[\d\.]*\/\d{1,2}\.',
         'Opera',
         ' \.NET[\d\.]*',
-        '\(|\)|;|,', // Remove the following characters ( ) : ,
+        ';', // Remove the following characters ;
     );
 }
