@@ -8,7 +8,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2016 Magic3 Project.
+ * @copyright  Copyright 2006-2018 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -37,6 +37,8 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 	const END_TIME_ID		= 'item_end_time';			// 公開期間終了時間タグID、タグ名
 	const START_BUTTON_ID	= 'calenderbutton1';			// 開始日用カレンダー表示ボタンのID
 	const END_BUTTON_ID		= 'calenderbutton2';			// 終了日用カレンダー表示ボタンのID
+	const OPEN_PANEL_ICON_FILE = '/images/system/plus32.png';		// 拡張エリア表示用アイコン
+	const CLOSE_PANEL_ICON_FILE = '/images/system/minus32.png';		// 拡張エリア非表示用アイコン
 	
 	/**
 	 * コンストラクタ
@@ -164,7 +166,7 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 		$marginRight = $request->trimValueOf('item_right');			// 右マージン
 		$title = $request->trimValueOf('item_title');			// タイトル名
 		$titleVisible = ($request->trimValueOf('item_title_visible') == 'on') ? 1 : 0;		// タイトルを表示するかどうか
-		$useRender = ($request->trimValueOf('item_use_render') == 'on') ? 1 : 0;		// Joomla!の描画処理を使用するかどうか
+		$useRender = ($request->trimValueOf('item_use_render') == 'on') ? 1 : 0;		// テンプレートの描画処理を使用するかどうか
 		$widgetId = $request->trimValueOf('widget_id');			// ウィジェットID
 		$topContent = $request->valueOf('item_top_content');			// 補助コンテンツ(上)
 		$bottomContent = $request->valueOf('item_bottom_content');			// 補助コンテンツ(下)
@@ -405,7 +407,7 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 			$marginRight = '';			// 右マージン
 			$title = '';			// タイトル名
 			$titleVisible = 1;		// タイトルを表示するかどうか
-			$useRender = 1;		// Joomla!の描画処理を使用するかどうか
+			$useRender = 1;		// テンプレートの描画処理を使用するかどうか
 			$widgetId = '';	// ウィジェットID
 			$topContent = '';			// 補助コンテンツ(上)
 			$bottomContent = '';			// 補助コンテンツ(下)
@@ -428,7 +430,10 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 			$cssClassSuffix = '';			// 追加CSSクラスサフィックス
 			$css = '';
 			$this->hTagLevel = 0;			// Hタグレベル
-				
+			
+			// 補助コンテンツエリアの表示制御
+			$isAdditionalContentArea = false;
+			
 			$replaceNew = true;
 		}
 		// 表示データ再取得
@@ -463,7 +468,7 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 				}
 				$title = $row['pd_title'];			// タイトル名
 				$titleVisible = $row['pd_title_visible'];			// タイトルを表示するかどうか
-				$useRender = $row['pd_use_render'];		// Joomla!の描画処理を使用するかどうか
+				$useRender = $row['pd_use_render'];		// テンプレートの描画処理を使用するかどうか
 				$widgetId = $row['pd_widget_id'];	// ウィジェットID
 				$topContent = $row['pd_top_content'];			// 補助コンテンツ(上)
 				$bottomContent = $row['pd_bottom_content'];			// 補助コンテンツ(下)
@@ -498,6 +503,9 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 				
 				// ウィジェット用CSS ID
 				$widgetCssId = $this->gPage->getWidgetCssId($row['pd_serial'], $row['pd_id'], $row['pd_sub_id'], $row['pd_position_id']);
+				
+				// 補助コンテンツエリアの表示制御
+				if (!empty($topContent) || !empty($bottomContent) || !empty($showReadmore)) $isAdditionalContentArea = true;		// 補助コンテンツ(上),補助コンテンツ(下),もっと読むボタン
 			}
 		}
 		
@@ -518,6 +526,21 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 		$this->tmpl->addVar('_widget', 'start_button_id', self::START_BUTTON_ID);// 開始日用カレンダー表示ボタンのID
 		$this->tmpl->addVar('_widget', 'end_button_id', self::END_BUTTON_ID);// 終了日用カレンダー表示ボタンのID
 		
+		// 補助コンテンツエリア表示制御
+		if ($isAdditionalContentArea){
+			$this->tmpl->addVar('_widget', 'additional_content_area_open', 'true');
+		} else {
+			$this->tmpl->addVar('_widget', 'additional_content_area_open', 'false');
+		}
+		$iconUrl = $this->gEnv->getRootUrl() . self::OPEN_PANEL_ICON_FILE;		// 拡張エリア表示用アイコン
+		$iconTitle = $this->_('Show additional content area');		// 補助コンテンツエリアを表示
+		$openButton = '<a id="button_open" href="javascript:void(0);" class="btn btn-sm btn-warning" role="button" rel="m3help" data-container="body" title="' . $iconTitle . '"><i class="glyphicon glyphicon-plus"></i></a>';
+		$this->tmpl->addVar('_widget', 'open_button', $openButton);
+		$iconUrl = $this->gEnv->getRootUrl() . self::CLOSE_PANEL_ICON_FILE;		// 拡張エリア非表示用アイコン
+		$iconTitle = $this->_('Hide additional content area');				// 補助コンテンツエリアを非表示
+		$closeButton = '<a id="button_close" href="javascript:void(0);" class="btn btn-sm btn-warning" role="button" rel="m3help" data-container="body" title="' . $iconTitle . '"><i class="glyphicon glyphicon-minus"></i></a>';
+		$this->tmpl->addVar('_widget', 'close_button', $closeButton);
+		
 		// ナビゲーションタブ作成
 		if (empty($activeTab)){		// タブの選択
 			$this->tmpl->addVar('_widget', 'active_tab', 'widget_config');
@@ -531,7 +554,7 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 		$this->tmpl->addVar("_widget", "right", 	$this->convertToDispString($marginRight));			// 右マージン
 		$this->tmpl->addVar("_widget", "title", 	$this->convertToDispString($title));				// タイトル名
 		if (!empty($titleVisible)) $this->tmpl->addVar("_widget", "title_visible", 'checked');		// タイトルを表示するかどうか
-		if (!empty($useRender)) $this->tmpl->addVar("_widget", "use_render", 'checked');		// Joomla!の描画処理を使用するかどうか
+		if (!empty($useRender)) $this->tmpl->addVar("_widget", "use_render", 'checked');		// テンプレートの描画処理を使用するかどうか
 		$this->tmpl->addVar("_widget", "widget_id", $this->convertToDispString($widgetId));				// ウィジェットID
 		$this->tmpl->addVar("_widget", "top_content", $topContent);			// 補助コンテンツ(上)
 		$this->tmpl->addVar("_widget", "bottom_content", $bottomContent);			// 補助コンテンツ(下)
@@ -734,7 +757,7 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 		$localeText['label_right'] = $this->_('Right:');			// 右：
 		$localeText['label_position'] = $this->_('Contents Position');			// テキスト表示位置
 		$localeText['label_render'] = $this->_('Render');// 描画処理
-		$localeText['label_use_joomla_render'] = $this->_('Render by Joomla! style');// Joomla!スタイルの描画処理を使用
+		$localeText['label_use_template_render'] = $this->_('Render by template');// テンプレートの描画処理を使用
 		$localeText['label_top_content'] = $this->_('Additional Top Content');// 補助コンテンツ(上)
 		$localeText['label_bottom_content'] = $this->_('Additional Bottom Content');// 補助コンテンツ(下)
 		$localeText['label_readmore'] = $this->_('Readmore Button');// 「もっと読む」ボタン
