@@ -55,6 +55,11 @@ class admin_blog_mainWidgetContainer extends admin_blog_mainBaseWidgetContainer
 				$task = 'entry';
 				$goWidget = true;		// サブウィジェットを実行するかどうか
 				break;
+			case self::TASK_SCHEDULE:	// ブログ記事予約(一覧)
+			case self::TASK_SCHEDULE_DETAIL:	// ブログ記事予約(詳細)
+				$task = self::TASK_SCHEDULE;
+				$goWidget = true;		// サブウィジェットを実行するかどうか
+				break;
 			case 'comment':		// ブログ記事コメント管理
 			case 'comment_detail':		// ブログ記事コメント管理(詳細)
 				$task = 'comment';
