@@ -8,7 +8,7 @@
  *
  * @package    カスタム検索
  * @author     株式会社 毎日メディアサービス
- * @copyright  Copyright 2010-2015 株式会社 毎日メディアサービス.
+ * @copyright  Copyright 2010-2018 株式会社 毎日メディアサービス.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.m-media.co.jp
@@ -380,6 +380,7 @@ class custom_searchWidgetContainer extends BaseWidgetContainer
 	function searchItemsLoop($index, $fetchedRow)
 	{
 		// コンテンツへのリンクを生成
+		$title = '';
 		$linkUrl = '';
 		$summary = '';		// コンテンツ概要
 		$contentType = $fetchedRow['type'];
@@ -403,6 +404,19 @@ class custom_searchWidgetContainer extends BaseWidgetContainer
 					// 検索結果用のテキスト作成
 					$summary = $this->_createSummaryText($content);
 				}
+				
+				// 固定コンテンツウィジェット等でコンテンツをページに直接埋め込んでいる場合はリンク先を修正
+				$ret = $this->_db->getSubPageIdByContent(M3_VIEW_TYPE_CONTENT, $contentId, $this->gEnv->getCurrentPageId(), $rows);
+				if ($ret){
+					$pageSubId = $rows[0]['pd_sub_id'];
+					$pageTitle = $rows[0]['pn_meta_title'];
+	
+					// ページタイトルが設定されている場合は取得
+					if (!empty($pageTitle)) $title = $pageTitle;
+					
+					// ページへのURLを作成
+					$linkUrl = $this->getUrl($this->gEnv->createPageUrl() . '?' . M3_REQUEST_PARAM_PAGE_SUB_ID . '=' . $pageSubId, true/*リンク用*/);
+				}
 				break;
 			case M3_VIEW_TYPE_USER:		// ユーザ作成コンテンツの場合
 				$roomId = $fetchedRow['id'];
@@ -587,9 +601,9 @@ class custom_searchWidgetContainer extends BaseWidgetContainer
 			default:
 				break;
 		}
-		$title = $fetchedRow['name'];
+		if (empty($title)) $title = $fetchedRow['name'];
 		$escapedTitle = $this->convertToDispString($title);
-		$titleLink = $this->convertToDispString($fetchedRow['name']);
+		$titleLink = $this->convertToDispString($title);
 		$escapedLinkUrl = $this->convertUrlToHtmlEntity($linkUrl);
 		if (!empty($linkUrl)) $titleLink = '<a href="' . $escapedLinkUrl . '" >' . $titleLink . '</a>';
 
