@@ -8,7 +8,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2015 Magic3 Project.
+ * @copyright  Copyright 2006-2017 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -24,10 +24,11 @@ class admin_ec_mainPhotoproductWidgetContainer extends admin_ec_mainBaseWidgetCo
 	private $langId;			// 言語
 	private $unitTypeId;		// 選択単位
 	private $currency;			// 通貨
+	private $defaultCurrencyId;	// デフォルトの通貨ID
 	private $taxType;			// 税種別
 	private $ecObj;			// 共通ECオブジェクト
 	const MAX_HIER_LEVEL = 20;		// カテゴリー階層最大値
-	const STANDARD_PRICE = 'selling';		// 通常価格
+	const REGULAR_PRICE = 'regular';		// 通常価格
 	const PRODUCT_IMAGE_MEDIUM = 'standard-product';		// 中サイズ商品画像ID
 	const PRODUCT_IMAGE_SMALL = 'small-product';		// 小サイズ商品画像ID
 	const PRODUCT_IMAGE_LARGE = 'large-product';		// 大サイズ商品画像ID
@@ -46,6 +47,8 @@ class admin_ec_mainPhotoproductWidgetContainer extends admin_ec_mainBaseWidgetCo
 		// DBオブジェクト作成
 		$this->db = new ec_mainPhotoProductDb();
 		
+		$this->defaultCurrencyId = $this->ecObj->getDefaultCurrency();	// デフォルトの通貨ID
+		
 		// EC用共通オブジェクト取得
 		$this->ecObj = $this->gInstance->getObject(self::PRICE_OBJ_ID);
 	}
@@ -315,7 +318,7 @@ class admin_ec_mainPhotoproductWidgetContainer extends admin_ec_mainBaseWidgetCo
 				$priceArray = array();
 				$startDt = $this->gEnv->getInitValueOfTimestamp();
 				$endDt = $this->gEnv->getInitValueOfTimestamp();
-				$priceArray[] = array(self::STANDARD_PRICE, $this->currency, $price, $startDt, $endDt);		// 単品商品で追加
+				$priceArray[] = array(self::REGULAR_PRICE, $this->currency, $price, $startDt, $endDt);		// 単品商品で追加
 				
 				// 画像情報の作成
 				$imageArray = array();
@@ -376,7 +379,7 @@ class admin_ec_mainPhotoproductWidgetContainer extends admin_ec_mainBaseWidgetCo
 				$priceArray = array();
 				$startDt = $this->gEnv->getInitValueOfTimestamp();
 				$endDt = $this->gEnv->getInitValueOfTimestamp();
-				$priceArray[] = array(self::STANDARD_PRICE, $this->currency, $price, $startDt, $endDt);		// 単品商品で追加
+				$priceArray[] = array(self::REGULAR_PRICE, $this->currency, $price, $startDt, $endDt);		// 単品商品で追加
 				
 				// 画像情報の作成
 				$imageArray = array();
@@ -494,7 +497,7 @@ class admin_ec_mainPhotoproductWidgetContainer extends admin_ec_mainBaseWidgetCo
 					$updateDt = $this->convertToDispDateTime($row['hp_create_dt']);	// 更新日時
 				
 					// 価格を取得
-					$priceArray = $this->getPrice($row2, self::STANDARD_PRICE);
+					$priceArray = $this->getPrice($row2, self::REGULAR_PRICE, $this->defaultCurrencyId);
 					$price = $priceArray['pp_price'];	// 価格
 					$this->currency = $priceArray['pp_currency_id'];	// 通貨
 				
@@ -512,7 +515,7 @@ class admin_ec_mainPhotoproductWidgetContainer extends admin_ec_mainBaseWidgetCo
 		// 各種価格を求める
 		$price = $this->ecObj->getCurrencyPrice($price);	// 端数調整
 		$this->ecObj->setCurrencyType($this->currency, $this->langId);		// 通貨設定
-		$this->ecObj->setTaxType($this->taxType, $this->langId);		// 税種別設定
+		$this->ecObj->setTaxType($this->taxType);		// 税種別設定
 		$totalPrice = $this->ecObj->getPriceWithTax($price, $dispPrice);	// 税込み価格取得
 		$delivPrice = $this->ecObj->getCurrencyPrice($delivPrice);	// 端数調整
 		
@@ -544,11 +547,11 @@ class admin_ec_mainPhotoproductWidgetContainer extends admin_ec_mainBaseWidgetCo
 		$this->db->getUnitType($defaultLang, array($this, 'unitTypeLoop'));
 
 		// 通貨タイプ選択メニュー作成
-		if ($this->gEnv->getMultiLanguage()){	// 多言語対応のとき
+/*		if ($this->gEnv->getMultiLanguage()){	// 多言語対応のとき
 			$this->db->getCurrency($defaultLang, array($this, 'currencyLoop'));
-		}
+		}*/
 		// 課税タイプ選択メニューの作成
-		$this->db->getTaxType($defaultLang, array($this, 'taxTypeLoop'));
+		$this->db->getTaxType(array($this, 'taxTypeLoop'));
 
 		// 商品画像プレビューの作成
 		// 画像小
@@ -645,14 +648,14 @@ class admin_ec_mainPhotoproductWidgetContainer extends admin_ec_mainBaseWidgetCo
 			$langId = $row['hp_language_id'];
 			
 			// 価格を取得
-			$priceArray = $this->getPrice($row2, self::STANDARD_PRICE);
+			$priceArray = $this->getPrice($row2, self::REGULAR_PRICE, $this->defaultCurrencyId);
 			$price = $priceArray['pp_price'];	// 価格
 			$currency = $priceArray['pp_currency_id'];	// 通貨
 			$taxType = $row['hp_tax_type_id'];					// 税種別			
 
 			// 価格作成
 			$this->ecObj->setCurrencyType($currency, $langId);		// 通貨設定
-			$this->ecObj->setTaxType($taxType, $langId);		// 税種別設定
+			$this->ecObj->setTaxType($taxType);		// 税種別設定
 			$totalPrice = $this->ecObj->getPriceWithTax($price, $dispPrice);	// 税込み価格取得
 			if (empty($taxType)) $dispPrice = '(未)';		// 税種別未選択のとき
 			
@@ -762,12 +765,13 @@ class admin_ec_mainPhotoproductWidgetContainer extends admin_ec_mainBaseWidgetCo
 	 *
 	 * @param array  	$srcRows			価格リスト
 	 * @param string	$priceType			価格のタイプ
+	 * @param string    $currencyId			通貨ID
 	 * @return array						取得した価格行
 	 */
-	function getPrice($srcRows, $priceType)
+	function getPrice($srcRows, $priceType, $currencyId)
 	{
 		for ($i = 0; $i < count($srcRows); $i++){
-			if ($srcRows[$i]['pp_price_type_id'] == $priceType){
+			if ($srcRows[$i]['pp_currency_id'] == $currencyId && $srcRows[$i]['pp_price_type_id'] == $priceType){
 				return $srcRows[$i];
 			}
 		}
