@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id$
+ * @version    SVN: $Id: admin_reserve_mainResourceWidgetContainer.php 642 2008-05-22 12:25:05Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() . '/admin_reserve_mainBaseWidgetContainer.php');
@@ -90,8 +90,7 @@ class admin_reserve_mainResourceWidgetContainer extends admin_reserve_mainBaseWi
 	{
 		global $gEnvManager;
 		
-		$pageNo = $request->trimValueOf('page');				// ページ番号
-		if (empty($pageNo)) $pageNo = 1;
+		$pageNo = $request->trimIntValueOf(M3_REQUEST_PARAM_PAGE_NO, '1');				// ページ番号
 		
 		// デフォルト値を取得
 		$maxListCount = self::DEFAULT_LIST_COUNT;	// 表示項目数
