@@ -565,7 +565,8 @@ class AttachFile
 	var $size_str = '';
 	var $status = array('count'=>array(0), 'age'=>'', 'pass'=>'', 'freeze'=>FALSE);
 
-	function AttachFile($page, $file, $age = 0)
+//	function AttachFile($page, $file, $age = 0)
+	function __construct($page, $file, $age = 0)
 	{
 		$this->page = $page;
 		$this->file = preg_replace('#^.*/#','',$file);
@@ -1013,7 +1014,8 @@ class AttachFiles
 	var $page;
 	var $files = array();
 
-	function AttachFiles($page)
+//	function AttachFiles($page)
+	function __construct($page)
 	{
 		$this->page = $page;
 	}
@@ -1082,7 +1084,8 @@ class AttachPages
 {
 	var $pages = array();
 
-	function AttachPages($page = '', $age = NULL)
+//	function AttachPages($page = '', $age = NULL)
+	function __construct($page = '', $age = NULL)
 	{
 		// アップロード用のディレクトリ内のファイルリストを取得
 		$dir = opendir(UPLOAD_DIR) or
